UNPKG

graphqldoc

Version:
235 lines (229 loc) 16.2 kB
<!DOCTYPE html> <html lang="en"> <head> <meta charset="utf-8" /> <meta http-equiv="x-ua-compatible" content="ie=edge" /> <meta name="viewport" content="width=device-width, initial-scale=1" /> <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet"> <link type="text/css" rel="stylesheet" href="./styles/graphdoc.css" /> <title>__Type | Pokémon GraphQL API</title> <link href="https://fonts.googleapis.com/css?family=Ubuntu+Mono:400,700" rel="stylesheet"><link type="text/css" rel="stylesheet" href="./assets/code.css" /><script src="./assets/line-link.js"></script><link type="text/css" rel="stylesheet" href="./assets/require-by.css" /> </head> <body class="slds-scrollable--y"> <nav class="slds-grid slds-grid--vertical slds-col--rule-right"> <header class="slds-p-around--medium slds-col slds-shrik slds-grow-none"> <button class="slds-button slds-button--icon slds-float--right js-toggle-navigation less-than-medium"> <i class="material-icons">close</i> </button> <a href="https://github.com/lucasbento/graphql-pokemon" target="_blank" style="display:block;padding:1rem 35%"><img src="https://raw.githubusercontent.com/lucasbento/graphql-pokemon/master/content/logo.png" /></a> <div class="slds-p-top--small"> <input id="type-search" type="text" placeholder="Search a type" autofocus="" class="slds-input" /> </div> </header> <div id="navication-scroll" class="slds-scrollable--y slds-col slds-grow"> <div class="slds-grid slds-grid--vertical slds-navigation-list--vertical"> <h4 class="slds-text-title--caps slds-p-around--medium">Schema</h4> <ul> <li title="Query"> <a href="query.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> Query </a> </li> </ul> </div> <div class="slds-grid slds-grid--vertical slds-navigation-list--vertical"> <h4 class="slds-text-title--caps slds-p-around--medium">Scalars</h4> <ul> <li title="Boolean"> <a href="boolean.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> Boolean </a> </li> <li title="Float"> <a href="float.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> Float </a> </li> <li title="ID"> <a href="id.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> ID </a> </li> <li title="Int"> <a href="int.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> Int </a> </li> <li title="String"> <a href="string.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> String </a> </li> </ul> </div> <div class="slds-grid slds-grid--vertical slds-navigation-list--vertical"> <h4 class="slds-text-title--caps slds-p-around--medium">Enums</h4> <ul> <li title="__DirectiveLocation"> <a href="directivelocation.spec.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> __DirectiveLocation </a> </li> <li title="__TypeKind"> <a href="typekind.spec.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> __TypeKind </a> </li> </ul> </div> <div class="slds-grid slds-grid--vertical slds-navigation-list--vertical"> <h4 class="slds-text-title--caps slds-p-around--medium">Objects</h4> <ul> <li title="Attack"> <a href="attack.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> Attack </a> </li> <li title="Pokemon"> <a href="pokemon.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> Pokemon </a> </li> <li title="PokemonAttack"> <a href="pokemonattack.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> PokemonAttack </a> </li> <li title="PokemonDimension"> <a href="pokemondimension.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> PokemonDimension </a> </li> <li title="PokemonEvolutionRequirement"> <a href="pokemonevolutionrequirement.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> PokemonEvolutionRequirement </a> </li> <li title="__Directive"> <a href="directive.spec.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> __Directive </a> </li> <li title="__EnumValue"> <a href="enumvalue.spec.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> __EnumValue </a> </li> <li title="__Field"> <a href="field.spec.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> __Field </a> </li> <li title="__InputValue"> <a href="inputvalue.spec.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> __InputValue </a> </li> <li title="__Schema"> <a href="schema.spec.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> __Schema </a> </li> <li class="slds-is-active" title="__Type"> <a href="type.spec.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> __Type </a> </li> </ul> </div> <div class="slds-grid slds-grid--vertical slds-navigation-list--vertical"> <h4 class="slds-text-title--caps slds-p-around--medium">Directives</h4> <ul> <li title="deprecated"> <a href="deprecated.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> deprecated </a> </li> <li title="include"> <a href="include.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> include </a> </li> <li title="skip"> <a href="skip.doc.html" class="slds-navigation-list--vertical__action slds-text-link--reset slds-truncate"> skip </a> </li> </ul> </div> </div> </nav> <main><section class="title slds-theme--inverse"> <div class="container slds-grid"> <div> <button class="slds-button js-toggle-navigation less-than-medium"> <i class="material-icons slds-button__icon slds-button__icon--left">menu</i> <span class="slds-text-title--caps">Types</span> </button> </div> <div class="slds-col--bump-left"> <a class="slds-button js-toggle-navigation" target="_blank" href="https:&#x2F;&#x2F;graphql-pokemon.now.sh&#x2F;"> <span class="slds-text-title--caps">GraphiQL</span> <i class="material-icons slds-button__icon slds-button__icon--rigth">open_in_new</i> </a> </div> </div> <div class="container"> <p class="slds-text-title--caps slds-text-color--weak">OBJECT</p> <h1 class="slds-text-heading--large">__Type</h1> <div class="slds-text-body--regular"><p>The fundamental unit of any GraphQL Schema is the type. There are many kinds of types in GraphQL as represented by the <code>__TypeKind</code> enum.</p> <p>Depending on the kind of a type, certain fields describe information about that type. Scalar types provide no information beyond a name and description, while Enum types provide their values. Object and Interface types provide the fields they describe. Abstract types, Union and Interface, provide the Object types possible at runtime. List and NonNull types compose other types.</p> </div> </div> </section> <section> <div class="container"> <h2 id="graphql-schema-definition" class="graphdoc-section__title slds-text-heading--medium slds-m-top--small"> <a href="#graphql-schema-definition"> <i class="material-icons">link</i> </a> GraphQL Schema definition </h2> <code class="highlight"><table class="code"><tbody><tr class="row"><td id="L1" class="td-index">1</td><td id="LC1" class="td-code"><span class="keyword operator ts">type</span> <span class="identifier">__Type</span> {</td></tr><tr class="row"><td id="L2" class="td-index">2</td><td id="LC2" class="td-code"></td></tr><tr class="row"><td id="L3" class="td-index">3</td><td id="LC3" class="td-code"><span class="tab"><span class="meta">kind</span>: <a class="support type" href="typekind.spec.html">__TypeKind</a>! </span></td></tr><tr class="row"><td id="L4" class="td-index">4</td><td id="LC4" class="td-code"></td></tr><tr class="row"><td id="L5" class="td-index">5</td><td id="LC5" class="td-code"><span class="tab"><span class="meta">name</span>: <a class="support type" href="string.doc.html">String</a> </span></td></tr><tr class="row"><td id="L6" class="td-index">6</td><td id="LC6" class="td-code"></td></tr><tr class="row"><td id="L7" class="td-index">7</td><td id="LC7" class="td-code"><span class="tab"><span class="meta">description</span>: <a class="support type" href="string.doc.html">String</a> </span></td></tr><tr class="row"><td id="L8" class="td-index">8</td><td id="LC8" class="td-code"></td></tr><tr class="row"><td id="L9" class="td-index">9</td><td id="LC9" class="td-code"><span class="tab"><span class="meta">fields</span>(<span class="meta">includeDeprecated</span>: <a class="support type" href="boolean.doc.html">Boolean</a>): [<a class="support type" href="field.spec.html">__Field</a>!] </span></td></tr><tr class="row"><td id="L10" class="td-index">10</td><td id="LC10" class="td-code"></td></tr><tr class="row"><td id="L11" class="td-index">11</td><td id="LC11" class="td-code"><span class="tab"><span class="meta">interfaces</span>: [<a class="support type" href="type.spec.html">__Type</a>!] </span></td></tr><tr class="row"><td id="L12" class="td-index">12</td><td id="LC12" class="td-code"></td></tr><tr class="row"><td id="L13" class="td-index">13</td><td id="LC13" class="td-code"><span class="tab"><span class="meta">possibleTypes</span>: [<a class="support type" href="type.spec.html">__Type</a>!] </span></td></tr><tr class="row"><td id="L14" class="td-index">14</td><td id="LC14" class="td-code"></td></tr><tr class="row"><td id="L15" class="td-index">15</td><td id="LC15" class="td-code"><span class="tab"><span class="meta">enumValues</span>(<span class="meta">includeDeprecated</span>: <a class="support type" href="boolean.doc.html">Boolean</a>): [<a class="support type" href="enumvalue.spec.html">__EnumValue</a>!] </span></td></tr><tr class="row"><td id="L16" class="td-index">16</td><td id="LC16" class="td-code"></td></tr><tr class="row"><td id="L17" class="td-index">17</td><td id="LC17" class="td-code"><span class="tab"><span class="meta">inputFields</span>: [<a class="support type" href="inputvalue.spec.html">__InputValue</a>!] </span></td></tr><tr class="row"><td id="L18" class="td-index">18</td><td id="LC18" class="td-code"></td></tr><tr class="row"><td id="L19" class="td-index">19</td><td id="LC19" class="td-code"><span class="tab"><span class="meta">ofType</span>: <a class="support type" href="type.spec.html">__Type</a> </span></td></tr><tr class="row"><td id="L20" class="td-index">20</td><td id="LC20" class="td-code"></td></tr><tr class="row"><td id="L21" class="td-index">21</td><td id="LC21" class="td-code">}</td></tr></tbody></table></code> </div> </section> <section> <div class="container"> <h2 id="required-by" class="graphdoc-section__title slds-text-heading--medium slds-m-top--small"> <a href="#required-by"> <i class="material-icons">link</i> </a> Required by </h2> <ul class="require-by"><li><a href="field.spec.html" title="__Field - Object and Interface types are described by a list of Fields, each of which has a name, potentially a list of arguments, and a return type.">__Field<em>Object and Interface types are described by a list of Fields, each of which has a name, potentially a list of arguments, and a return type.</em></a><li><li><a href="inputvalue.spec.html" title="__InputValue - Arguments provided to Fields or Directives and the input fields of an InputObject are represented as Input Values which describe their type and optionally a default value.">__InputValue<em>Arguments provided to Fields or Directives and the input fields of an InputObject are represented as Input Values which describe their type and optionally a default value.</em></a><li><li><a href="schema.spec.html" title="__Schema - A GraphQL Schema defines the capabilities of a GraphQL server. It exposes all available types and directives on the server, as well as the entry points for query, mutation, and subscription operations.">__Schema<em>A GraphQL Schema defines the capabilities of a GraphQL server. It exposes all available types and directives on the server, as well as the entry points for query, mutation, and subscription operations.</em></a><li><li><a href="type.spec.html" title="__Type - The fundamental unit of any GraphQL Schema is the type. There are many kinds of types in GraphQL as represented by the `__TypeKind` enum. Depending on the kind of a type, certain fields describe information about that type. Scalar types provide no information beyond a name and description, while Enum types provide their values. Object and Interface types provide the fields they describe. Abstract types, Union and Interface, provide the Object types possible at runtime. List and NonNull types compose other types.">__Type<em>The fundamental unit of any GraphQL Schema is the type. There are many kinds of types in GraphQL as represented by the `__TypeKind` enum. Depending on the kind of a type, certain fields describe information about that type. Scalar types provide no information beyond a name and description, while Enum types provide their values. Object and Interface types provide the fields they describe. Abstract types, Union and Interface, provide the Object types possible at runtime. List and NonNull types compose other types.</em></a><li></ul> </div> </section> <footer> <div class="container slds-p-around--large"> <p class="slds-text-align--right slds-text-title--caps"> Generated with <a href="https://github.com/CodeSignal/graphqldoc#readme" target="_blank">graphqldoc 2.5.1</a> </p> </div> </footer> </main> <script src="./scripts/focus-active.js"></script> <script src="./scripts/filter-types.js"></script> <script src="./scripts/toggle-navigation.js"></script> <script> (function (i, s, o, g, r, a, m) { i['GoogleAnalyticsObject'] = r; i[r] = i[r] || function () { (i[r].q = i[r].q || []).push(arguments) }, i[r].l = 1 * new Date(); a = s.createElement(o), m = s.getElementsByTagName(o)[0]; a.async = 1; a.src = g; m.parentNode.insertBefore(a, m) })(window, document, 'script', 'https://www.google-analytics.com/analytics.js', 'ga'); ga('create', 'UA-54154153-2', 'auto'); ga('send', 'pageview'); </script> </body>